@@ -13,7 +13,7 @@ import pandas
 from shapely import ops
 from shapely.geometry import MultiPolygon, Polygon
 from shapely.geometry.base import BaseGeometry
-from stormevents.coops import coops_stations, coops_stations_within_region
+from searvey.coops import coops_stations, coops_stations_within_region
 from stormevents.nhc import VortexTrack
 import typepigeon
 
